#
# spec file for package firecracker
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Use hardening ldflags.
%define cargo_home cargo-home

Name:           firecracker
Version:        0.19.1
Release:        lp152.1.5
Summary:        Virtual Machine Monitor for creating microVMs
License:        Apache-2.0
Group:          System/Emulators/PC
URL:            https://firecracker-microvm.github.io/
Source0:        %{name}-%{version}.tar.xz
# Created using cargo_vendor service
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  rust >= 1.35.0
%ifarch aarch64
BuildRequires:  libfdt-devel
%endif
ExclusiveArch:  x86_64 aarch64

%description
Firecracker is a virtualization technology for creating and managing
multi-tenant container and function-based services.

%prep
%setup -q -a1

mkdir %{cargo_home}
cat > %{cargo_home}/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

# Copying the file elsewhere is required, because rpm build for aarch64
# tries to change all the config.guess files found in BUILD with
# some arch specific stuff.
rm -rf $HOME/rust/%{name}
mkdir -pv $HOME/rust/%{name}
find . -mindepth 1 -maxdepth 1 -exec cp -r {} $HOME/rust/%{name} \;

%build
cd $HOME/rust/%{name}
# This should eventually migrate to distro policy
# Enable optimization, debuginfo, and link hardening.
export CARGO_HOME=`pwd`/%{cargo_home}/

cargo install \
  --path `pwd` \
  --root=%{buildroot}%{_prefix} \
  --target %{_arch}-unknown-linux-gnu

%install
# remove spurious file
rm -f %{buildroot}%{_prefix}/.crates.toml
rm -f %{buildroot}%{_prefix}/.crates2.json

%files
%doc README.md
%{_bindir}/firecracker
%{_bindir}/jailer

%changelog
* Mon May 25 2020 Liang Yan <lyan@suse.com>
- Update firecracker to version 0.19.1:
  Added:
  * New device: virtio-vsock, backed by Unix domain sockets.
  * New command-line parameter for firecracker, named --no-api, which
    will disable the API server thread. Also, when API server is disabled,
    MMDS is no longer available now.
  * New command-line parameter for firecracker, named --config-file, which
    represents the path to a file that contains a JSON which can be used for
    configuring and starting a microVM without sending any API requests.
  * The jailer adheres to the "end of command options" convention, meaning
    all parameters specified after -- are forwarded verbatim to Firecracker.
  * Added KVM_PTP support to the recommended guest kernel config.
  * Added entry in FAQ.md for Firecracker Guest timekeeping.
  Changed:
  * Vsock API call: PUT /vsocks/{id} changed to PUT /vsock and no longer
    appear to support multiple vsock devices. Any subsequent calls to this API
    endpoint will override the previous vsock device configuration.
  Removed:
  * Removed experimental support for vhost-based vsock devices.
  * Removed unused 'Halting' and 'Halted' instance states.
* Mon May 25 2020 Liang Yan <lyan@suse.com>
- Modify spec file:
  * Change the group to "System/Emulators/PC" which is maintained by virt team.
  * Use "rm -f " instead of "rm" to remove spurious files
  * Remove macro "_missing_doc_files_terminate_build"
* Sun May 24 2020 Liang Yan <lyan@suse.com>
- Fix Tumbelweed builds by removing /usr/.crates2.json.
* Fri Sep 13 2019 Jan Engelhardt <jengelh@inai.de>
- Trim marketing wording from description.
* Tue Sep 10 2019 Marco Vedovati <mvedovati@suse.com>
- Fix aarch64 builds
- Bump min rust version to 1.35.0
* Mon Sep  9 2019 Marco Vedovati <mvedovati@suse.com>
- Update firecracker to version 0.17.0:
  Added:
  * New API call: PATCH /machine-config/, used to update VM configuration,
    before the microVM boots.
  * Added an experimental swagger definition that includes the specification
    for the vsock API call.
  * Added a signal handler for SIGBUS and SIGSEGV that immediately terminates
    the process upon intercepting the signal.
  * Added documentation for signal handling utilities.
  * Added [alpha] aarch64 support.
  * Added metrics for successful read and write operations of MMDS, Net and
    Block devices.
  Changed:
  * vcpu_count, mem_size_mib and ht_enabled have been changed to be mandatory
    for PUT requests on /machine-config/.
  * Disallow invalid seccomp levels by exiting with error.
  Fixed:
  * Incorrect handling of bind mounts within the jailed rootfs.
  * Corrected the guide for Alpine guest setup.
* Wed May 29 2019 Marco Vedovati <mvedovati@suse.com>
- Update firecracker to version 0.16.0:
    + Added [alpha] AMD support.
  * Corrected the seccomp filter when building with glibc.
  - Removed the seccomp.bad_syscalls metric.
  * Dropped the JSON-formatted context command-line parameter from Firecracker
    in favor of individual classic command-line parameters.
  * Improved multiple error messages.
  * Removed all kernel modules from the recommended kernel config.
* Mon May  6 2019 Marco Vedovati <mvedovati@suse.com>
- Fixed vsock support (needed for katacontainers interoperability)
  * Use `cargo install` to build and install build artifacts
  during the build phase, to avoid building the crate twice.
* Sat Mar 23 2019 Flavio Castelli <fcastelli@suse.com>
- Added patches 0001-Fixed-basic-seccomp-filter-for-glibc.patch and
  0002-Fixed-advanced-seccomp-filter-for-glibc.patch: change the
  seccomp filtering rules to allow the execution of certain syscalls
  that are used when the binary is built with glibc instead of musl.
* Fri Mar 22 2019 Flavio Castelli <fcastelli@suse.com>
- Ensure build happens only on supported architectures
- Enable vsock experimental feature
* Fri Mar 15 2019 opensuse Cloud User <fcastelli@suse.com>
- Make spec file arch independent
* Thu Mar 14 2019 Flavio Castelli <fcastelli@suse.com>
- Initial package version 0.15.2
